<script setup>
import { computed, reactive } from 'vue';
import { Link } from '@inertiajs/inertia-vue3';

const props = defineProps({
    href: {
        type: String,
        default: '',
    },
    active: {
        type: Boolean,
        default: false,
    },
    badge: {
        type: Boolean,
        default: false,
    }
});

const activeClasses = computed(() => {
    return props.active
        ? 'active bg-navItem-active border-whiteItem-4 text-whiteItem-4'
        : 'idle border-whiteItem-1 text-whiteItem-2 hover:text-whiteItem-3 hover:bg-navItem-idlehover';
});

const badgeClasses = computed(() => {
    return props.badge
        ? 'visible'
        : 'hiddenBadge';
});

</script>

<style scoped>
    .active{
        border-bottom-width: 1px;
        border-bottom-style: solid;
        box-shadow: 0 4px 6px -1px rgba(0, 0, 0, 0.1), 0 2px 4px -1px rgba(0, 0, 0, 0.06);
        font-weight: 600;
    }

    .idle{
        font-weight: 500;
    }

    .idle:hover{
        border-bottom-width: 1px;
        border-bottom-style: solid;
    }

    .defaultNavItem{
        height: 100%;
        display: flex;
        justify-content: center;
        align-items: center;
        display: inline-flex;
        font-size: 1rem;
        padding-left: 1rem;
        padding-right: 1rem;
        position: relative;
        white-space: nowrap;
    }

    .defaultBadge{
        position: absolute;
        top: 4px;
        right: 4px;
        font-size: 0.75rem;
    }

    .hiddenBadge{
        display: none !important;
    }

    .animate-rolling{
        animation: rolling 1s cubic-bezier(0, 0, 0.2, 1) infinite;
    }

    @keyframes rolling {
        0%, 10% {
            transform: rotate(-8deg);
        }
        10%, 20% {
            transform: rotate(8deg);
        }
        20%, 30% {
            transform: rotate(-8deg);
        }
        30%, 40% {
            transform: rotate(8deg);
        }
        40%, 50% {
            transform: rotate(-8deg);
        }
        50%, 60% {
            transform: rotate(8deg);
        }
        60%, 70% {
            transform: rotate(-8deg);
        }
        70%, 80% {
            transform: rotate(8deg);
        }
        80%, 90% {
        }
        90%, 100% {
        }
    }

</style>

<template>
    <Link v-if="href !== ''" :href="href" onclick="window.emitter.emit('changeLoaderStatus', true, 'orbit')" class="defaultNavItem" :class="[activeClasses]">

        <i class="defaultBadge fa-solid fa-bell animate-rolling text-whiteItem-4" :class="[badgeClasses]"></i>
        <slot/>
    </Link>
    <div v-else class="defaultNavItem" :class="[activeClasses]">
        <slot/>
    </div>
</template>

<script>
export default {
    data() {
        return {
        };
    },
    methods: {
    },
}
</script>